@@ -30,7 +30,7 @@
  * to enable truncation errors to be measured easily.
  **********************************************************************/
 #  define GEOGRAPHICLIB_AUXLATITUDE_ORDER \
-  (GEOGRAPHICLIB_PRECISION == 2 || GEOGRAPHICLIB_PRECISION == 5 ? 6 : \
+  (GEOGRAPHICLIB_PRECISION == 2 || GEOGRAPHICLIB_PRECISION >= 5 ? 6 : \
    (GEOGRAPHICLIB_PRECISION == 1 ? 4 : 8))
 #endif
 
@@ -386,7 +386,7 @@ namespace GeographicLib {
     { using std::hypot; return hypot(real(1), tphi); }
     // the function tphi / sqrt(1 + tphi^2), convert tan to sin
     static real sn(real tphi) {
-      using std::isinf; using std::copysign;
+      using std::isinf, std::copysign;
       return isinf(tphi) ? copysign(real(1), tphi) : tphi / sc(tphi);
     }
     // Populate [_c[Lmax * k], _c[Lmax * (k + 1)])
